"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const iterare_1 = require("iterare");
const fs = require("mz/fs");
const path = require("path");
const rimraf = require("rimraf");
const temp = require("temp");
const fs_1 = require("../fs");
const util_1 = require("../util");
const chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);
const assert = chai.assert;
describe('fs.ts', () => {
    describe('LocalFileSystem', () => {
        let temporaryDir;
        let fileSystem;
        let baseUri;
        before(() => __awaiter(this, void 0, void 0, function* () {
            temporaryDir = yield new Promise((resolve, reject) => {
                temp.mkdir('local-fs', (err, dirPath) => err ? reject(err) : resolve(dirPath));
            });
            baseUri = util_1.path2uri('', temporaryDir) + '/';
            yield fs.mkdir(path.join(temporaryDir, 'foo'));
            yield fs.mkdir(path.join(temporaryDir, '@types'));
            yield fs.mkdir(path.join(temporaryDir, '@types', 'diff'));
            yield fs.writeFile(path.join(temporaryDir, 'tweedledee'), 'hi');
            yield fs.writeFile(path.join(temporaryDir, 'tweedledum'), 'bye');
            yield fs.writeFile(path.join(temporaryDir, 'foo', 'bar.ts'), 'baz');
            yield fs.writeFile(path.join(temporaryDir, '@types', 'diff', 'index.d.ts'), 'baz');
            fileSystem = new fs_1.LocalFileSystem(util_1.toUnixPath(temporaryDir));
        }));
        after(() => __awaiter(this, void 0, void 0, function* () {
            yield new Promise((resolve, reject) => {
                rimraf(temporaryDir, err => err ? reject(err) : resolve());
            });
        }));
        describe('getWorkspaceFiles()', () => {
            it('should return all files in the workspace', () => __awaiter(this, void 0, void 0, function* () {
                assert.sameMembers(iterare_1.default(yield fileSystem.getWorkspaceFiles()).toArray(), [
                    baseUri + 'tweedledee',
                    baseUri + 'tweedledum',
                    baseUri + 'foo/bar.ts',
                    baseUri + '%40types/diff/index.d.ts'
                ]);
            }));
            it('should return all files under specific root', () => __awaiter(this, void 0, void 0, function* () {
                assert.sameMembers(iterare_1.default(yield fileSystem.getWorkspaceFiles(baseUri + 'foo')).toArray(), [
                    baseUri + 'foo/bar.ts'
                ]);
            }));
        });
        describe('getTextDocumentContent()', () => {
            it('should read files denoted by relative URI', () => __awaiter(this, void 0, void 0, function* () {
                assert.equal(yield fileSystem.getTextDocumentContent('tweedledee'), 'hi');
            }));
            it('should read files denoted by absolute URI', () => __awaiter(this, void 0, void 0, function* () {
                assert.equal(yield fileSystem.getTextDocumentContent(baseUri + 'tweedledee'), 'hi');
            }));
        });
    });
});
//# sourceMappingURL=fs.test.js.map